@@ -78,6 +78,7 @@ cifs_read_super(struct super_block *sb, void *data,
 	struct cifs_sb_info *cifs_sb;
 	int rc = 0;
 
+	sb->s_flags |= MS_NODIRATIME; /* and probably even noatime */
 	sb->s_fs_info = kmalloc(sizeof(struct cifs_sb_info),GFP_KERNEL);
 	cifs_sb = CIFS_SB(sb);
 	if(cifs_sb == NULL)
@@ -409,18 +410,20 @@ cifs_read_wrapper(struct file * file, char *read_data, size_t read_size,
 	else if(file->f_dentry->d_inode == NULL)
 		return -EIO;
 
+	cFYI(1,("In read_wrapper size %d at %lld",read_size,*poffset));
 	if(CIFS_I(file->f_dentry->d_inode)->clientCanCacheRead) {
 		return generic_file_read(file,read_data,read_size,poffset);
 	} else {
 		/* BB do we need to lock inode from here until after invalidate? */
-		if(file->f_dentry->d_inode->i_mapping) {
+/*		if(file->f_dentry->d_inode->i_mapping) {
 			filemap_fdatawrite(file->f_dentry->d_inode->i_mapping);
 			filemap_fdatawait(file->f_dentry->d_inode->i_mapping);
-		}
-		/* force read from the server since we do not have oplock */
-		/* BB we should relax this and do it on a timer and call cifs_revalidate */
-		/* BB we should make timer configurable */
-		invalidate_remote_inode(file->f_dentry->d_inode);
+		}*/
+/*		cifs_revalidate(file->f_dentry);*/ /* BB fixme */
+
+		/* BB we should make timer configurable - perhaps 
+		   by simply calling cifs_revalidate here */
+		/* invalidate_remote_inode(file->f_dentry->d_inode);*/
 		return generic_file_read(file,read_data,read_size,poffset);
 	}
 }
@@ -438,6 +441,8 @@ cifs_write_wrapper(struct file * file, const char *write_data,
 	else if(file->f_dentry->d_inode == NULL)
 		return -EIO;
 
+	cFYI(1,("In write_wrapper size %d at %lld",write_size,*poffset));
+
 	/* check whether we can cache writes locally */
 	written = generic_file_write(file,write_data,write_size,poffset);
 	if(!CIFS_I(file->f_dentry->d_inode)->clientCanCacheAll)  {
@@ -631,12 +636,14 @@ static int cifs_oplock_thread(void * dummyarg)
 				netfid = oplock_item->netfid;
 				spin_unlock(&GlobalMid_Lock);
 				DeleteOplockQEntry(oplock_item);
+				down(&inode->i_sem);
 				if (S_ISREG(inode->i_mode)) {
 					rc = filemap_fdatawrite(inode->i_mapping);
 					if(CIFS_I(inode)->clientCanCacheRead == 0)
 						invalidate_remote_inode(inode);
 				} else
 					rc = 0;
+				up(&inode->i_sem);
 				if (rc)
 					CIFS_I(inode)->write_behind_rc = rc;
 				cFYI(1,("Oplock flush inode %p rc %d",inode,rc));
