@@ -30,7 +30,6 @@
 #include <linux/fs.h>
 #include <linux/kernel.h>
 #include <linux/vfs.h>
-#include <linux/version.h>
 #include <asm/uaccess.h>
 #include "cifspdu.h"
 #include "cifsglob.h"
@@ -49,7 +48,7 @@ static struct {
 
 /* Mark as invalid, all open files on tree connections since they
    were closed when session to server was lost */
-void mark_open_files_invalid(struct cifsTconInfo * pTcon)
+static void mark_open_files_invalid(struct cifsTconInfo * pTcon)
 {
 	struct cifsFileInfo *open_file = NULL;
 	struct list_head * tmp;
@@ -67,12 +66,11 @@ void mark_open_files_invalid(struct cifsTconInfo * pTcon)
 	/* BB Add call to invalidate_inodes(sb) for all superblocks mounted to this tcon */
 }
 
-int
+static int
 smb_init(int smb_command, int wct, struct cifsTconInfo *tcon,
 	 void **request_buf /* returned */ ,
 	 void **response_buf /* returned */ )
 {
-	int timeout = 10 * HZ;
 	int rc = 0;
 
 	/* SMBs NegProt, SessSetup, uLogoff do not have tcon yet so
@@ -85,20 +83,19 @@ smb_init(int smb_command, int wct, struct cifsTconInfo *tcon,
 					reconnect, should be greater than cifs socket
 					timeout which is 7 seconds */
 			while(tcon->ses->server->tcpStatus == CifsNeedReconnect) {
-		                while ((tcon->ses->server->tcpStatus != CifsGood) && (timeout > 0)){
-					timeout = interruptible_sleep_on_timeout(&tcon->ses->server->response_q,timeout);
-				}
+				wait_event_interruptible_timeout(tcon->ses->server->response_q,
+					(tcon->ses->server->tcpStatus == CifsGood), 10 * HZ);
 				if(tcon->ses->server->tcpStatus == CifsNeedReconnect) {
-				/* on "soft" mounts we wait once */
-					if((tcon->retry == FALSE) ||
+					/* on "soft" mounts we wait once */
+					if((tcon->retry == FALSE) || 
 					   (tcon->ses->status == CifsExiting)) {
 						cFYI(1,("gave up waiting on reconnect in smb_init"));
 						return -EHOSTDOWN;
-					} /* else "hard" mount - keep retrying until
+					} /* else "hard" mount - keep retrying until 
 					process is killed or server comes back up */
 				} else /* TCP session is reestablished now */
 					break;
-
+				 
 			}
 			
 			nls_codepage = load_nls_default();
@@ -106,7 +103,7 @@ smb_init(int smb_command, int wct, struct cifsTconInfo *tcon,
 		simultaneously reconnect the same SMB session */
 			down(&tcon->ses->sesSem);
 			if(tcon->ses->status == CifsNeedReconnect)
-				rc = setup_session(0, tcon->ses, nls_codepage);
+				rc = cifs_setup_session(0, tcon->ses, nls_codepage);
 			if(!rc && (tcon->tidStatus == CifsNeedReconnect)) {
 				mark_open_files_invalid(tcon);
 				rc = CIFSTCon(0, tcon->ses, tcon->treeName, tcon,
@@ -145,7 +142,7 @@ smb_init(int smb_command, int wct, struct cifsTconInfo *tcon,
 	if(rc)
 		return rc;
 
-	*request_buf = buf_get();
+	*request_buf = cifs_buf_get();
 	if (request_buf == 0) {
 		return -ENOMEM;
 	}
@@ -196,11 +193,11 @@ CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses)
 	if (rc == 0) {
 		server->secMode = pSMBr->SecurityMode;	
 		server->secType = NTLM; /* BB override default for NTLMv2 or krb*/
-        /* one byte - no need to convert this or EncryptionKeyLen from le,*/
+		/* one byte - no need to convert this or EncryptionKeyLen from le,*/
 		server->maxReq = le16_to_cpu(pSMBr->MaxMpxCount);
 		/* probably no need to store and check maxvcs */
 		server->maxBuf =
-		    min(le32_to_cpu(pSMBr->MaxBufferSize),
+			min(le32_to_cpu(pSMBr->MaxBufferSize),
 			(__u32) CIFS_MAX_MSGSIZE + MAX_CIFS_HDR_SIZE);
 		server->maxRw = le32_to_cpu(pSMBr->MaxRawSize);
 		cFYI(0, ("Max buf = %d ", ses->server->maxBuf));
@@ -248,7 +245,6 @@ CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses)
 							 pSMBr->ByteCount -
 							 16, &server->secType);
 			}
-
 		} else
 			server->capabilities &= ~CAP_EXTENDED_SECURITY;
 		if(sign_CIFS_PDUs == FALSE) {        
@@ -263,7 +259,7 @@ CIFSSMBNegotiate(unsigned int xid, struct cifsSesInfo *ses)
 				
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	return rc;
 }
 
@@ -320,7 +316,7 @@ CIFSSMBTDis(const int xid, struct cifsTconInfo *tcon)
 		cFYI(1, (" Tree disconnect failed %d", rc));
 
 	if (smb_buffer)
-		buf_release(smb_buffer);
+		cifs_buf_release(smb_buffer);
 	up(&tcon->tconSem);
 
 	/* No need to return error on this operation if tid invalidated and 
@@ -354,8 +350,8 @@ CIFSSMBLogoff(const int xid, struct cifsSesInfo *ses)
 	rc = smb_init(SMB_COM_LOGOFF_ANDX, 2, 0 /* no tcon anymore */,
 		 (void **) &pSMB, (void **) &smb_buffer_response);
 
-        if(ses->server->secMode & (SECMODE_SIGN_REQUIRED | SECMODE_SIGN_ENABLED))
-                pSMB->hdr.Flags2 |= SMBFLG2_SECURITY_SIGNATURE;
+	if(ses->server->secMode & (SECMODE_SIGN_REQUIRED | SECMODE_SIGN_ENABLED))
+		pSMB->hdr.Flags2 |= SMBFLG2_SECURITY_SIGNATURE;
 
 	if (rc) {
 		up(&ses->sesSem);
@@ -373,7 +369,7 @@ CIFSSMBLogoff(const int xid, struct cifsSesInfo *ses)
 			ses->server->tcpStatus = CifsExiting;
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	up(&ses->sesSem);
 
 	/* if session dead then we do not need to do ulogoff,
@@ -424,7 +420,7 @@ DelFileRetry:
 		cFYI(1, ("Error in RMFile = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto DelFileRetry;
 
@@ -470,7 +466,7 @@ RmDirRetry:
 		cFYI(1, ("Error in RMDir = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto RmDirRetry;
 	return rc;
@@ -515,7 +511,7 @@ MkDirRetry:
 		cFYI(1, ("Error in Mkdir = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto MkDirRetry;
 	return rc;
@@ -603,7 +599,7 @@ openRetry:
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto openRetry;
 	return rc;
@@ -630,9 +626,9 @@ CIFSSMBRead(const int xid, struct cifsTconInfo *tcon,
 	if (rc)
 		return rc;
 
-        /* tcon and ses pointer are checked in smb_init */
-        if (tcon->ses->server == NULL)
-                return -ECONNABORTED;
+	/* tcon and ses pointer are checked in smb_init */
+	if (tcon->ses->server == NULL)
+		return -ECONNABORTED;
 
 	pSMB->AndXCommand = 0xFF;	/* none */
 	pSMB->Fid = netfid;
@@ -670,7 +666,7 @@ CIFSSMBRead(const int xid, struct cifsTconInfo *tcon,
 	}
 	if (pSMB) {
 		if(*buf)
-			buf_release(pSMB);
+			cifs_buf_release(pSMB);
 		else
 			*buf = (char *)pSMB;
 	}
@@ -729,7 +725,7 @@ CIFSSMBWrite(const int xid, struct cifsTconInfo *tcon,
 		*nbytes = le16_to_cpu(pSMBr->Count);
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	/* Note: On -EAGAIN error only caller can retry on handle based calls 
 		since file handle passed in no longer valid */
@@ -743,59 +739,58 @@ CIFSSMBLock(const int xid, struct cifsTconInfo *tcon,
 	    const __u64 offset, const __u32 numUnlock,
 	    const __u32 numLock, const __u8 lockType, const int waitFlag)
 {
-		int rc = 0;
-		LOCK_REQ *pSMB = NULL;
-		LOCK_RSP *pSMBr = NULL;
-		int bytes_returned;
-		int timeout = 0;
-		__u64 temp;
-
-		cFYI(1, ("In CIFSSMBLock"));
-		rc = smb_init(SMB_COM_LOCKING_ANDX, 8, tcon, (void **) &pSMB,
-				  (void **) &pSMBr);
-		if (rc)
-			return rc;
-
-		if(lockType == LOCKING_ANDX_OPLOCK_RELEASE) {
-			timeout = -1; /* no response expected */
-			pSMB->Timeout = 0;
-		} else if (waitFlag == TRUE) {
-			timeout = 3; /* blocking operation, no timeout */
-			pSMB->Timeout = -1; /* blocking - do not time out */
-		} else {
-			pSMB->Timeout = 0;
-		}
-
-		pSMB->NumberOfLocks = cpu_to_le32(numLock);
-		pSMB->NumberOfUnlocks = cpu_to_le32(numUnlock);
-		pSMB->LockType = lockType;
-		pSMB->AndXCommand = 0xFF;	/* none */
-		pSMB->Fid = smb_file_id; /* netfid stays le */
-
-		pSMB->Locks[0].Pid = cpu_to_le16(current->tgid);
-		temp = cpu_to_le64(len);
-		pSMB->Locks[0].LengthLow = (__u32)(len & 0xFFFFFFFF);
-		pSMB->Locks[0].LengthHigh =  (__u32)(len>>32);
-		temp = cpu_to_le64(offset);
-		pSMB->Locks[0].OffsetLow = (__u32)(offset & 0xFFFFFFFF);
-		pSMB->Locks[0].OffsetHigh = (__u32)(offset>>32);
-		pSMB->ByteCount = sizeof (LOCKING_ANDX_RANGE);
-		pSMB->hdr.smb_buf_length += pSMB->ByteCount;
-		pSMB->ByteCount = cpu_to_le16(pSMB->ByteCount);
-
-		rc = SendReceive(xid, tcon->ses, (struct smb_hdr *) pSMB,
-				 (struct smb_hdr *) pSMBr, &bytes_returned, timeout);
-
-		if (rc) {
-			cERROR(1, ("Send error in Lock = %d", rc));
-		}
-		if (pSMB)
-			buf_release(pSMB);
-
-		/* Note: On -EAGAIN error only caller can retry on handle based calls
-		since file handle passed in no longer valid */
+	int rc = 0;
+	LOCK_REQ *pSMB = NULL;
+	LOCK_RSP *pSMBr = NULL;
+	int bytes_returned;
+	int timeout = 0;
+	__u64 temp;
 
+	cFYI(1, ("In CIFSSMBLock - timeout %d numLock %d",waitFlag,numLock));
+	rc = smb_init(SMB_COM_LOCKING_ANDX, 8, tcon, (void **) &pSMB,
+		      (void **) &pSMBr);
+	if (rc)
 		return rc;
+
+	if(lockType == LOCKING_ANDX_OPLOCK_RELEASE) {
+		timeout = -1; /* no response expected */
+		pSMB->Timeout = 0;
+	} else if (waitFlag == TRUE) {
+		timeout = 3;  /* blocking operation, no timeout */
+		pSMB->Timeout = -1; /* blocking - do not time out */
+	} else {
+		pSMB->Timeout = 0;
+	}
+
+	pSMB->NumberOfLocks = cpu_to_le32(numLock);
+	pSMB->NumberOfUnlocks = cpu_to_le32(numUnlock);
+	pSMB->LockType = lockType;
+	pSMB->AndXCommand = 0xFF;	/* none */
+	pSMB->Fid = smb_file_id; /* netfid stays le */
+
+	pSMB->Locks[0].Pid = cpu_to_le16(current->tgid);
+	temp = cpu_to_le64(len);
+	pSMB->Locks[0].LengthLow = (__u32)(len & 0xFFFFFFFF);
+	pSMB->Locks[0].LengthHigh =  (__u32)(len>>32);
+	temp = cpu_to_le64(offset);
+	pSMB->Locks[0].OffsetLow = (__u32)(offset & 0xFFFFFFFF);
+	pSMB->Locks[0].OffsetHigh = (__u32)(offset>>32);
+	pSMB->ByteCount = sizeof (LOCKING_ANDX_RANGE);
+	pSMB->hdr.smb_buf_length += pSMB->ByteCount;
+	pSMB->ByteCount = cpu_to_le16(pSMB->ByteCount);
+
+	rc = SendReceive(xid, tcon->ses, (struct smb_hdr *) pSMB,
+			 (struct smb_hdr *) pSMBr, &bytes_returned, timeout);
+
+	if (rc) {
+		cERROR(1, ("Send error in Lock = %d", rc));
+	}
+	if (pSMB)
+		cifs_buf_release(pSMB);
+
+	/* Note: On -EAGAIN error only caller can retry on handle based calls 
+	since file handle passed in no longer valid */
+	return rc;
 }
 
 int
@@ -824,7 +819,7 @@ CIFSSMBClose(const int xid, struct cifsTconInfo *tcon, int smb_file_id)
 		cERROR(1, ("Send error in Close = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	/* Since session is dead, file will be closed on server already */
 	if(rc == -EAGAIN)
@@ -895,7 +890,7 @@ renameRetry:
 		cFYI(1, ("Send error in rename = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto renameRetry;
@@ -971,7 +966,7 @@ int CIFSSMBRenameOpenFile(const int xid,struct cifsTconInfo *pTcon,
 	}
 
 	if (pSMB)
-                buf_release(pSMB);
+                cifs_buf_release(pSMB);
 
 	/* Note: On -EAGAIN error only caller can retry on handle based calls
 		since file handle passed in no longer valid */
@@ -1064,7 +1059,7 @@ createSymLinkRetry:
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto createSymLinkRetry;
@@ -1153,7 +1148,7 @@ createHardLinkRetry:
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto createHardLinkRetry;
 
@@ -1224,7 +1219,7 @@ winCreateHardLinkRetry:
 		cFYI(1, ("Send error in hard link (NT rename) = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto winCreateHardLinkRetry;
 
@@ -1303,38 +1298,25 @@ querySymLinkRetry:
 			rc = -EIO;	/* bad smb */
 		else {
 			if (pSMBr->hdr.Flags2 & SMBFLG2_UNICODE) {
-#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,4,15))
 				name_len = UniStrnlen((wchar_t *) ((char *)
 					&pSMBr->hdr.Protocol +pSMBr->DataOffset),
 					min_t(const int, buflen,pSMBr->DataCount) / 2);
-#else
-                                name_len = UniStrnlen((wchar_t *) ((char *)
-                                        &pSMBr->hdr.Protocol +pSMBr->DataOffset),
-                                        min(buflen,pSMBr->DataCount) / 2);
-#endif
 				cifs_strfromUCS_le(symlinkinfo,
 					(wchar_t *) ((char *)&pSMBr->hdr.Protocol +
 						pSMBr->DataOffset),
 					name_len, nls_codepage);
 			} else {
-#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,4,15))
 				strncpy(symlinkinfo,
 					(char *) &pSMBr->hdr.Protocol + 
 						pSMBr->DataOffset,
 					min_t(const int, buflen, pSMBr->DataCount));
-#else
-                                strncpy(symlinkinfo,
-                                        (char *) &pSMBr->hdr.Protocol +
-                                                pSMBr->DataOffset,
-                                        min(buflen, pSMBr->DataCount));
-#endif
 			}
 			symlinkinfo[buflen] = 0;
 	/* just in case so calling code does not go off the end of buffer */
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto querySymLinkRetry;
 	return rc;
@@ -1404,15 +1386,9 @@ CIFSSMBQueryReparseLinkInfo(const int xid, struct cifsTconInfo *tcon,
 						reparse_buf->TargetNameOffset),
 						name_len, nls_codepage);
 				} else { /* ASCII names */
-#if (LINUX_VERSION_CODE > KERNEL_VERSION(2,4,15))
 					strncpy(symlinkinfo,reparse_buf->LinkNamesBuf + 
 						reparse_buf->TargetNameOffset, 
 						min_t(const int, buflen, reparse_buf->TargetNameLen));
-#else
-                                        strncpy(symlinkinfo,reparse_buf->LinkNamesBuf +
-                                                reparse_buf->TargetNameOffset,
-                                                min(buflen, reparse_buf->TargetNameLen));
-#endif
 				}
 			} else {
 				rc = -EIO;
@@ -1424,7 +1400,7 @@ CIFSSMBQueryReparseLinkInfo(const int xid, struct cifsTconInfo *tcon,
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	/* Note: On -EAGAIN error only caller can retry on handle based calls
 		since file handle passed in no longer valid */
@@ -1507,7 +1483,7 @@ QPathInfoRetry:
 		    rc = -ENOMEM;
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto QPathInfoRetry;
 
@@ -1590,7 +1566,7 @@ UnixQPathInfoRetry:
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto UnixQPathInfoRetry;
 
@@ -1668,7 +1644,7 @@ findUniqueRetry:
 		/* BB fill in */
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto findUniqueRetry;
 
@@ -1775,7 +1751,7 @@ findFirstRetry:
 		memcpy(findData, response_data, le16_to_cpu(pSMBr->DataCount));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto findFirstRetry;
@@ -1880,7 +1856,7 @@ CIFSFindNext(const int xid, struct cifsTconInfo *tcon,
 		memcpy(findData, response_data, le16_to_cpu(pSMBr->DataCount));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	/* Note: On -EAGAIN error only caller can retry on handle based calls
 		since file handle passed in no longer valid */
@@ -1914,7 +1890,7 @@ CIFSFindClose(const int xid, struct cifsTconInfo *tcon, const __u16 searchHandle
 		cERROR(1, ("Send error in FindClose = %d", rc));
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	/* Since session is dead, search handle closed on server already */
 	if (rc == -EAGAIN)
@@ -2076,7 +2052,7 @@ getDFSRetry:
 
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto getDFSRetry;
@@ -2086,7 +2062,7 @@ getDFSRetry:
 
 int
 CIFSSMBQFSInfo(const int xid, struct cifsTconInfo *tcon,
-	       struct statfs *FSData, const struct nls_table *nls_codepage)
+	       struct kstatfs *FSData, const struct nls_table *nls_codepage)
 {
 /* level 0x103 SMB_QUERY_FILE_SYSTEM_INFO */
 	TRANSACTION2_QFSI_REQ *pSMB = NULL;
@@ -2150,13 +2126,14 @@ QFSInfoRetry:
 			FSData->f_bfree = FSData->f_bavail =
 			    le64_to_cpu(response_data->FreeAllocationUnits);
 			cFYI(1,
-			     ("Blocks: %ld  Free: %ld Block size %ld",
-			      FSData->f_blocks, FSData->f_bfree,
+			     ("Blocks: %lld  Free: %lld Block size %ld",
+			      (unsigned long long)FSData->f_blocks,
+			      (unsigned long long)FSData->f_bfree,
 			      FSData->f_bsize));
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto QFSInfoRetry;
@@ -2223,7 +2200,7 @@ QFSAttributeRetry:
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto QFSAttributeRetry;
@@ -2292,7 +2269,7 @@ QFSDeviceRetry:
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto QFSDeviceRetry;
@@ -2360,7 +2337,7 @@ QFSUnixRetry:
 		}
 	}
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto QFSUnixRetry;
@@ -2457,7 +2434,7 @@ SetEOFRetry:
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto SetEOFRetry;
@@ -2477,7 +2454,7 @@ CIFSSMBSetFileSize(const int xid, struct cifsTconInfo *tcon, __u64 size,
 	int bytes_returned = 0;
 	__u32 tmp;
 
-	cFYI(1, ("SetFileSize (via SetFileInfo)"));
+	cFYI(1, ("SetFileSize (via SetFileInfo) %lld",size));
 	rc = smb_init(SMB_COM_TRANSACTION2, 15, tcon, (void **) &pSMB,
 		      (void **) &pSMBr);
 	if (rc)
@@ -2546,9 +2523,9 @@ CIFSSMBSetFileSize(const int xid, struct cifsTconInfo *tcon, __u64 size,
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
- 	/* Note: On -EAGAIN error only caller can retry on handle based calls 
+	/* Note: On -EAGAIN error only caller can retry on handle based calls 
 		since file handle passed in no longer valid */
 
 	return rc;
@@ -2625,7 +2602,7 @@ SetTimesRetry:
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 
 	if (rc == -EAGAIN)
 		goto SetTimesRetry;
@@ -2707,7 +2684,7 @@ setPermsRetry:
 	}
 
 	if (pSMB)
-		buf_release(pSMB);
+		cifs_buf_release(pSMB);
 	if (rc == -EAGAIN)
 		goto setPermsRetry;
 	return rc;
